
"""The base command."""


class Base(object):
    """A base command."""

    def __init__(self, path, options, *args, **kwargs):
        self.options = options
        self.args = args
        self.kwargs = kwargs
        self.path = path;
        
    def run(self):
        raise NotImplementedError('You must implement the run() method yourself!')
        


"""
xudo
Usage:
  xudo logs (api | changelog | migrations | rcash)
  xudo pull
  xudo build [-c -m -s -e -r -a -x]
  xudo test (be | app | admin | core | it)
  xudo watch
  xudo debug (php | hbng (app | admin | core))
  xudo fix
  xudo clean
  xudo -h | --help
  xudo --version
Examples:
  xudo logs api
  xudo build -cms
  xudo debug hbng app
Options:
  -c                                Changelog
  -m                                Migrations
  -s                                Sql
  -e                                Email
  -r                                Rcash
  -a                                Api
  -x                                Api no cache
  be                                Backend
  it                                Integration Test
  For additional help using this tool, ask the asian dude that sits over there *points*
  or email luke@honestbuildings.com
  or visit https://github.com/Ostralyan/xudo
"""


from inspect import getmembers, isclass

from docopt import docopt

from . import __version__ as VERSION

import requests 

import os


def main():
    """Main CLI entrypoint."""
    import xudo.commands
    options = docopt(__doc__, version=VERSION)

    # Here we'll try to dynamically match the command the user is trying to run
    # with a pre-defined command class we've already created.
    path = get_path()
    for (k, v) in options.items(): 
        if hasattr(xudo.commands, k) and v:
            module = getattr(xudo.commands, k)
            xudo.commands = getmembers(module, isclass)
            command = [command[1] for command in xudo.commands if command[0] != 'Base'][0]
            command = command(path, options)
            command.run()

    completion_notification()

def get_path():
  return open(os.path.join(os.path.expanduser('~'),'.xudo_profile')).read().strip();

def completion_notification():
    text = "Done"
    os.system("osascript -e \'display notification \"" + text + "!\" with title \"xudo\"'");



"""The logs command."""


from json import dumps

from .base import Base

import os, subprocess


class Fix(Base):
    """Docker logs"""

    def run(self):
        statusText = subprocess.Popen(['git status'], shell=True, stdout=subprocess.PIPE).communicate()[0]
        if "" in statusText:
            print("yes")
        else:
            print("no")


"""The logs command."""


from json import dumps

from .base import Base

import os


class Logs(Base):
    """Docker logs"""

    def run(self):
        if self.options["api"]:
            os.system("docker logs api_api_1 -f")
        elif self.options["changelog"]:
            os.system("docker logs api_changelog_1 -f")
        elif self.options["migrations"]:
            os.system("docker logs api_migrations_1 -f")
        elif self.options["rcash"]:
            os.system("docker logs api_rcash_1 -f")


"""The logs command."""


from json import dumps

from .base import Base

import os, sys


class Clean(Base):
    """Say hello, world!"""

    def run(self):
        os.system("docker rmi $(docker images --quiet --filter \"dangling=true\")")



"""The logs command."""


from json import dumps

from .base import Base

import os, sys


class Debug(Base):
    """Say hello, world!"""

    def run(self):
        hbngPath = os.path.join(self.path, "hbng")

        if self.options["php"]:
            os.system("docker exec api_api_1 /bin/sh -c \"sed -ie '\\$axdebug\.remote_host=192\.168\.65\.1' /etc/php/5.6/mods-available/xdebug.ini\"")
            os.system("docker exec api_api_1 /bin/sh -c \"sed -ie '\\$axdebug\.remote_connect_back=0' /etc/php/5.6/mods-available/xdebug.ini\"")
            os.system("docker exec api_api_1 /bin/sh -c \"service php5.6-fpm restart\"")
        elif self.options["hbng"]:
            if self.options["app"]:
                os.chdir(hbngPath)
                os.system("./debugKarma.sh app")
            elif self.options["admin"]:
                os.chdir(hbngPath)
                os.system("./debugKarma.sh admin")
            elif self.options["core"]:
                os.chdir(hbngPath)
                os.system("./debugKarma.sh core")
            



"""The logs command."""


from json import dumps

from .base import Base

import os


class Test(Base):
    """Say hello, world!"""

    def run(self):
        javaPath = os.path.join(self.path, "api/java")
        hbngPath = os.path.join(self.path, "hbng")
        testPath = os.path.join(self.path, "api/test")

        if self.options["be"]:
            os.chdir(javaPath)
            os.system("./gradlew clean build test")
        elif self.options["app"]:
            os.chdir(hbngPath)
            os.system("gulp karma-hb-app")
        elif self.options["admin"]:
            os.chdir(hbngPath)
            os.system("gulp karma-hb-admin")
        elif self.options["core"]:
            os.chdir(hbngPath)
            os.system("gulp karma-hb-core")
        elif self.options["it"]:
            os.chdir(testPath)
            os.system("gulp mocha")



"""The logs command."""


from json import dumps

from .base import Base

import os


class Watch(Base):
    """Say hello, world!"""

    def run(self):
        hbngPath = os.path.join(self.path, "hbng")

        os.chdir(hbngPath)
        os.system('gulp watch -d')
